@@ -187,6 +187,39 @@ class Info(API):
         """
         return self.post("/info", {"type": "userFills", "user": address})
 
+    def user_fills_by_time(self, address: str, start_time: int, end_time: Optional[int] = None) -> Any:
+        """Retrieve a given user's fills by time.
+
+        POST /info
+
+        Args:
+            address (str): Onchain address in 42-character hexadecimal format;
+                            e.g. 0x0000000000000000000000000000000000000000.
+            start_time (int): Unix timestamp in milliseconds
+            end_time (Optional[int]): Unix timestamp in milliseconds
+
+        Returns:
+            [
+              {
+                closedPnl: float string,
+                coin: str,
+                crossed: bool,
+                dir: str,
+                hash: str,
+                oid: int,
+                px: float string,
+                side: str,
+                startPosition: float string,
+                sz: float string,
+                time: int
+              },
+              ...
+            ]
+        """
+        return self.post(
+            "/info", {"type": "userFillsByTime", "user": address, "startTime": start_time, "endTime": end_time}
+        )
+
     def meta(self) -> Meta:
         """Retrieve exchange perp metadata
 
@@ -475,9 +508,6 @@ class Info(API):
     def query_user_to_multi_sig_signers(self, multi_sig_user: str) -> Any:
         return self.post("/info", {"type": "userToMultiSigSigners", "user": multi_sig_user})
 
-    def query_signer_to_multi_sig_user(self, signer: str) -> Any:
-        return self.post("/info", {"type": "signerToMultiSigUser", "signer": signer})
-
     def subscribe(self, subscription: Subscription, callback: Callable[[Any], None]) -> int:
         if subscription["type"] == "l2Book" or subscription["type"] == "trades" or subscription["type"] == "candle":
             subscription["coin"] = self.name_to_coin[subscription["coin"]]
